import { registerCodeBlockRenderer } from ".";
import { SvelteCodeBlockRenderer } from "./SvelteCodeBlockRenderer";
import BookshelfCodeBlockView from "./BookshelfCodeBlockView.svelte";
import type BookTrackerPlugin from "@src/main";
import z from "zod/v4";

export function registerBookshelfCodeBlockProcessor(
	plugin: BookTrackerPlugin
): void {
	registerCodeBlockRenderer(
		plugin,
		"bookshelf",
		(source, el) => new BookshelfCodeBlockRenderer(plugin, source, el)
	);
}

export const BookshelfSettingsSchema = z.object({
	titleProperty: z.string(),
	subtitleProperty: z.optional(z.string()),
	authorsProperty: z.string(),
});

export class BookshelfCodeBlockRenderer extends SvelteCodeBlockRenderer<
	typeof BookshelfCodeBlockView
> {
	constructor(
		plugin: BookTrackerPlugin,
		source: string,
		contentEl: HTMLElement
	) {
		super(contentEl, BookshelfCodeBlockView, { props: { plugin, source } });
	}

	onunload() {}
}
